# a patch against news_controller
# to add the link to send_notification sitewide on show action.
ActiveSupport::Reloader.to_prepare do
  unless NewsController.included_modules.include?(SitewideNews::NewsControllerPatch)
    NewsController.send(:include, SitewideNews::NewsControllerPatch)
  end
end

require_dependency "news_controller"

module SitewideNews
  module NewsControllerPatch
    def self.included(base) # :nodoc:
      base.send(:include, InstanceMethods)
      # base.extend(ClassMethods)

      base.class_eval do
        unloadable
        before_action :authorize, :except => [:index, :send_notification_sitewide]
      end
    end

    module InstanceMethods
      def send_notification_sitewide
        begin
          # see ${plugin_root}/app/lib/news_patch.rb
          if @news.send_notification_sitewide
            respond_to do |format|
              format.html {
                render_attachment_warning_if_needed(@news)
                flash[:notice] = l(:notice_successful_sitewide_news)
                redirect_to news_path(@news)
              }
              format.api { render_api_ok }
            end
          else
            respond_to do |format|
              format.html {
                render_attachment_warning_if_needed(@news)
                flash[:notice] = l(:notice_failed_sitewide_news)
                redirect_to news_path(@news)
              }
              format.api { render_validation_errors(@news) }
            end
          end
        rescue => e
          Rails.logger.error e
          Rails.logger.error e.backtrace.join("\n")
        end
      end
    end

    # module ClassMethods
    # end
  end
end
