# a patch against News model
# to reroute its Mailer model call to SitewideNewsMailer
ActiveSupport::Reloader.to_prepare do
  require_dependency 'news'
  unless News.included_modules.include?(SitewideNews::NewsPatch)
    News.send(:include, SitewideNews::NewsPatch)
  end
end

module SitewideNews
  module NewsPatch
    def self.included(base) # :nodoc:
      base.send(:include, InstanceMethods)
      base.extend(ClassMethods)

      base.class_eval do
        unloadable
      end
    end

    module InstanceMethods
      def send_notification_sitewide
        begin
          if self.project.module_enabled?(:news) && User.current.allowed_to?(:send_notification_sitewide, self.project)
            SitewideNewsMailer.deliver_news_added_sitewide(self)
          end
        rescue => e
          Rails.logger.error e
          Rails.logger.error e.backtrace.join("\n") 
        end
      end    
    end
    # used on ${plugin_root}/views/news/show.html.erb
    module ClassMethods
      def News.submit_sitewide_confirmation_message
        message = l(:text_submit_news_sitewide_confirmation)
      
        recipients_count = User.where(:status => '1', :type => 'User').count
        if recipients_count > 0
          message << "\n" + l(:text_submit_news_sitewide_recipients_confirmation, :count => recipients_count)
        end
        message
      end
    end
    
  end
end

